@@ -5,6 +5,9 @@ from ..exceptions import ValidationError, ConversionError, ModelValidationError,
 from ..transforms import export_loop, EMPTY_LIST, EMPTY_DICT
 from .base import BaseType
 
+from six import iteritems
+from six import string_types as basestring
+from six import text_type as unicode
 
 class MultiType(BaseType):
 
@@ -186,7 +189,7 @@ class ListType(MultiType):
             try:
                 self.field.validate(item)
             except ValidationError as exc:
-                errors.append(exc.message)
+                errors += exc.messages
 
         if errors:
             raise ValidationError(errors)
@@ -198,7 +201,7 @@ class ListType(MultiType):
                     role=None, print_none=False):
         """Loops over each item in the model and applies either the field
         transform or the multitype transform.  Essentially functions the same
-        as `serialize.export_loop`.
+        as `transforms.export_loop`.
         """
         data = []
         for value in list_instance:
@@ -255,11 +258,11 @@ class DictType(MultiType):
             raise ValidationError(u'Only dictionaries may be used in a DictType')
 
         return dict((self.coerce_key(k), self.field.to_native(v, context))
-                    for k, v in value.iteritems())
+                    for k, v in iteritems(value))
 
     def validate_items(self, items):
         errors = {}
-        for key, value in items.iteritems():
+        for key, value in iteritems(items):
             try:
                 self.field.validate(value)
             except ValidationError as exc:
@@ -270,17 +273,17 @@ class DictType(MultiType):
 
     def to_primitive(self, value, context=None):
         return dict((unicode(k), self.field.to_primitive(v, context))
-                    for k, v in value.iteritems())
+                    for k, v in iteritems(value))
 
     def export_loop(self, dict_instance, field_converter,
                     role=None, print_none=False):
         """Loops over each item in the model and applies either the field
         transform or the multitype transform.  Essentially functions the same
-        as `serialize.export_loop`.
+        as `transforms.export_loop`.
         """
         data = {}
 
-        for key, value in dict_instance.iteritems():
+        for key, value in iteritems(dict_instance):
             if hasattr(self.field, 'export_loop'):
                 shaped = self.field.export_loop(value, field_converter,
                                                 role=role)
