@@ -7,6 +7,13 @@ from schematics.types.compound import ModelType, DictType, ListType
 from schematics.types.serializable import serializable
 from schematics.transforms import blacklist, whitelist, wholelist, export_loop
 
+import six
+from six import iteritems
+try:
+    unicode #PY2
+except:
+    import codecs
+    unicode = str #PY3
 
 def test_serializable():
     class Location(Model):
@@ -620,15 +627,15 @@ def test_serializable_with_dict_and_roles():
     class Game(Model):
         id = StringType()
         result = IntType()
-        players = DictType(ModelType(Player), coerce_key=lambda k: long(k))
+        players = DictType(ModelType(Player), coerce_key=lambda k: int(k))
 
         class Options:
             roles = {
                 "public": blacklist("result")
             }
 
-    p1 = Player({"id": 1L, "display_name": "A"})
-    p2 = Player({"id": 2L, "display_name": "B"})
+    p1 = Player({"id": 1, "display_name": "A"})
+    p2 = Player({"id": 2, "display_name": "B"})
 
     game = Game({
         "id": "1",
@@ -646,10 +653,10 @@ def test_serializable_with_dict_and_roles():
     assert d == {
         "id": "1",
         "players": {
-            1L: {
+            1: {
                 "display_name": "A"
             },
-            2L: {
+            2: {
                 "display_name": "B"
             },
         }
@@ -713,7 +720,7 @@ def test_role_set_operations():
             n += 1
 
     class User(Model):
-        id = IntType(default=count(42).next)
+        id = IntType(default=six.next(count(42)))
         name = StringType()
         email = StringType()
         password = StringType()
@@ -754,7 +761,7 @@ def test_role_set_operations():
 
     user = User(
         dict(
-            (k, v) for k, v in data.iteritems()
+            (k, v) for k, v in iteritems(data)
             if k in User._options.roles['create']  # filter by 'create' role
         )
     )
